==> funbot-0.2.tar.gz: funbot-0.2/README.md <==
# funbot

An IRC bot for learning, fun and collaboration in the Freepost community.
There is a project page [here][proj].

## Using

See the .cabal file for more info and link to project website and version
control.

The official download location is the Git repository:

<https://notabug.org/fr33domlover/funbot.git>

Occasionally, releases may be made to Hackage, the Haskell package repository.
See <http://hackage.haskell.org/package/funbot>.

Some of the dependency libraries may have recent features not released to
Hackage yet. See the guide linked at the bottom for their clone URLs. If you
use a released version of funbot, you can safely install all the dependencies
from Hackage as usual.

This program is free software, and is committed to software freedom. It is
released to the public domain using the CC0 Public Domain Dedication. For the
boring "legal" details see the file 'COPYING'.

See the file 'INSTALL' for hints on installation. The file 'ChangeLog' explains
how to see the history log of the changes done in the code. 'NEWS' provides a
friendly overview of the changes for each release.

## Reporting Bugs and Suggesting Features

If you found a bug, or you have an idea, a feature request or a wishlist item,
open a ticket for it! Even if you're goint to implement something or try to
solve it.

This project uses [Rel4tion][rel4tion]'s [ticket system][rel4tkt]. See the
[project page][proj] for details.

You *can* open an issue in NotABug if you prefer, and it will then be moved to
Rel4tion's ticket system. But it is generally preferred you use that system
directly.

## User/Contributor Guide

There is a detailed guide for running the bot and creating a development setup.
It's [here][guide]. If anything happens and it's unavailable, there is a
(maybe lagging 1-2 hours behind) mirror of the guide source [here][mirror].

If you're going to implement some feature or fix some bug you found,
**start by opening a ticket** so that other people will know which features are
being developed and who does what.

[proj]: http://rel4tion.org/projects/funbot/
[rel4tion]: http://rel4tion.org/
[rel4tkt]: http://rel4tion.org/tickets/
[guide]: http://rel4tion.org/projects/funbot/guide/
[mirror]: https://notabug.org/fr33domlover/Rel4tion-Wiki/src/master/projects/funbot.mdwn

==> funbot-0.4.0.1.tar.gz: funbot-0.4.0.1/README.md <==
# funbot

An IRC bot for learning, fun and collaboration in the Freepost community.
There is a project page [here][proj].

## Using

See the .cabal file for more info and link to project website and version
control.

The official download location is the Git repository:

<https://notabug.org/fr33domlover/funbot.git>

Occasionally, releases may be made to Hackage, the Haskell package repository.
See <http://hackage.haskell.org/package/funbot>.

Some of the dependency libraries may have recent features not released to
Hackage yet. See the guide linked at the bottom for their clone URLs. If you
use a released version of funbot, you can safely install all the dependencies
from Hackage as usual.

This program is free software, and is committed to software freedom. It is
released to the public domain using the CC0 Public Domain Dedication. For the
boring "legal" details see the file `COPYING`.

See the file `INSTALL.md` for a detailed usage and deployment guide. The file
`ChangeLog` explains how to see the history log of the changes done in the
code. `NEWS.md` provides a friendly overview of the changes for each release.

## Reporting Bugs and Suggesting Features

If you found a bug, or you have an idea, a feature request or a wishlist item,
open a ticket for it! Even if you're goint to implement something or try to
solve it.

Use NotABug's issue system.

## User/Contributor Guide

There is a detailed guide for running the bot and creating a development setup.
It's in the `INSTALL.md` file.

If you're going to implement some feature or fix some bug you found,
**start by opening an issue** so that other people will know which features are
being developed and who does what.

[proj]: http://rel4tion.org/projects/funbot/
[rel4tion]: http://rel4tion.org/
